About
--------------------------------------------

cccontact is a minimal contact form system for Django that plays nicely with all of the other designcc django apps.

For more information consult the `documentation`_


.. _documentation: http://django-cccontact.readthedocs.org/en/latest/
